@@ -1,11 +1,13 @@
 import copy
+import sys
 import time
-import warnings
-from collections import OrderedDict
+import traceback
+from collections import OrderedDict, defaultdict
 
 import cloudpickle
 import numpy as np
 import pandas as pd
+import woodwork as ww
 from sklearn.model_selection import (
     BaseCrossValidator,
     KFold,
@@ -16,21 +18,27 @@ from sklearn.model_selection import (
 from .pipeline_search_plots import PipelineSearchPlots
 
 from evalml.automl.automl_algorithm import IterativeAlgorithm
-from evalml.automl.data_splitters import TrainingValidationSplit
+from evalml.automl.callbacks import log_error_callback
+from evalml.automl.data_splitters import (
+    TimeSeriesSplit,
+    TrainingValidationSplit
+)
 from evalml.automl.utils import get_default_primary_search_objective
 from evalml.data_checks import (
     AutoMLDataChecks,
     DataChecks,
     DefaultDataChecks,
-    EmptyDataChecks
+    EmptyDataChecks,
+    HighVarianceCVDataCheck
 )
-from evalml.data_checks.data_check_message_type import DataCheckMessageType
 from evalml.exceptions import (
     AutoMLSearchException,
     PipelineNotFoundError,
     PipelineScoreError
 )
+from evalml.model_family import ModelFamily
 from evalml.objectives import (
+    get_all_objective_names,
     get_core_objectives,
     get_non_core_objectives,
     get_objective
@@ -46,6 +54,10 @@ from evalml.pipelines.utils import make_pipeline
 from evalml.problem_types import ProblemTypes, handle_problem_types
 from evalml.tuners import SKOptTuner
 from evalml.utils import convert_to_seconds, get_random_state
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper
+)
 from evalml.utils.logger import (
     get_logger,
     log_subtitle,
@@ -69,7 +81,6 @@ class AutoMLSearch:
     def __init__(self,
                  problem_type=None,
                  objective='auto',
-                 max_pipelines=None,
                  max_iterations=None,
                  max_time=None,
                  patience=None,
@@ -79,13 +90,17 @@ class AutoMLSearch:
                  allowed_model_families=None,
                  start_iteration_callback=None,
                  add_result_callback=None,
+                 error_callback=None,
                  additional_objectives=None,
                  random_state=0,
                  n_jobs=-1,
                  tuner_class=None,
                  verbose=True,
                  optimize_thresholds=False,
-                 _max_batches=None):
+                 ensembling=False,
+                 max_batches=None,
+                 problem_configuration=None,
+                 _pipelines_per_batch=5):
         """Automated pipeline search
 
         Arguments:
@@ -98,9 +113,6 @@ class AutoMLSearch:
                 - LogLossMulticlass for multiclass classification problems, and
                 - R2 for regression problems.
 
-            max_pipelines (int): Will be deprecated in the next release. Maximum number of pipelines to search. If max_pipelines and
-                max_time is not set, then max_pipelines will default to max_pipelines of 5.
-
             max_iterations (int): Maximum number of iterations to search. If max_iterations and
                 max_time is not set, then max_iterations will default to max_iterations of 5.
 
@@ -124,15 +136,20 @@ class AutoMLSearch:
                 to `multiclass` or `regression` depending on the problem type. Note that if allowed_pipelines is provided,
                 this parameter will be ignored.
 
-            data_split (sklearn.model_selection.BaseCrossValidator): data splitting method to use. Defaults to StratifiedKFold.
+            data_split (sklearn.model_selection.BaseCrossValidator): Data splitting method to use. Defaults to StratifiedKFold.
 
-            tuner_class: the tuner class to use. Defaults to scikit-optimize tuner
+            tuner_class: The tuner class to use. Defaults to SKOptTuner.
 
-            start_iteration_callback (callable): function called before each pipeline training iteration.
-                Passed three parameters: pipeline_class, parameters, and the AutoMLSearch object.
+            start_iteration_callback (callable): Function called before each pipeline training iteration.
+                Callback function takes three positional parameters: The pipeline class, the pipeline parameters, and the AutoMLSearch object.
 
-            add_result_callback (callable): function called after each pipeline training iteration.
-                Passed three parameters: A dictionary containing the training results for the new pipeline, an untrained_pipeline containing the parameters used during training, and the AutoMLSearch object.
+            add_result_callback (callable): Function called after each pipeline training iteration.
+                Callback function takes three positional parameters:: A dictionary containing the training results for the new pipeline, an untrained_pipeline containing the parameters used during training, and the AutoMLSearch object.
+
+            error_callback (callable): Function called when `search()` errors and raises an Exception.
+                Callback function takes three positional parameters: the Exception raised, the traceback, and the AutoMLSearch object.
+                Must also accepts kwargs, so AutoMLSearch is able to pass along other appropriate parameters by default.
+                Defaults to None, which will call `log_error_callback`.
 
             additional_objectives (list): Custom set of objectives to score on.
                 Will override default objectives for problem type if not empty.
@@ -142,10 +159,19 @@ class AutoMLSearch:
             n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines.
                 None and 1 are equivalent. If set to -1, all CPUs are used. For n_jobs below -1, (n_cpus + 1 + n_jobs) are used.
 
-            verbose (boolean): If True, turn verbosity on. Defaults to True
+            verbose (boolean): If True, turn verbosity on. Defaults to True.
 
-            _max_batches (int): The maximum number of batches of pipelines to search. Parameters max_time, and
+            ensembling (boolean): If True, runs ensembling in a separate batch after every allowed pipeline class has been iterated over.
+                If the number of unique pipelines to search over per batch is one, ensembling will not run. Defaults to False.
+
+            max_batches (int): The maximum number of batches of pipelines to search. Parameters max_time, and
                 max_iterations have precedence over stopping the search.
+
+            problem_configuration (dict, None): Additional parameters needed to configure the search. For example,
+                in time series problems, values should be passed in for the gap and max_delay variables.
+
+            _pipelines_per_batch (int): The number of pipelines to train for every batch after the first one.
+                The first batch will train a baseline pipline + one of each pipeline family allowed in the search.
         """
         try:
             self.problem_type = handle_problem_types(problem_type)
@@ -155,16 +181,18 @@ class AutoMLSearch:
         self.tuner_class = tuner_class or SKOptTuner
         self.start_iteration_callback = start_iteration_callback
         self.add_result_callback = add_result_callback
+        self.error_callback = error_callback or log_error_callback
         self.data_split = data_split
         self.verbose = verbose
         self.optimize_thresholds = optimize_thresholds
+        self.ensembling = ensembling
         if objective == 'auto':
             objective = get_default_primary_search_objective(self.problem_type.value)
         objective = get_objective(objective, return_instance=False)
         self.objective = self._validate_objective(objective)
         if self.data_split is not None and not issubclass(self.data_split.__class__, BaseCrossValidator):
             raise ValueError("Not a valid data splitter")
-        if self.problem_type != self.objective.problem_type:
+        if not objective.is_defined_for_problem_type(self.problem_type):
             raise ValueError("Given objective {} is not compatible with a {} problem.".format(self.objective.name, self.problem_type.value))
         if additional_objectives is None:
             additional_objectives = get_core_objectives(self.problem_type)
@@ -177,22 +205,21 @@ class AutoMLSearch:
         additional_objectives = [self._validate_objective(obj) for obj in additional_objectives]
         self.additional_objectives = additional_objectives
 
-        if max_time is None or isinstance(max_time, (int, float)):
-            self.max_time = max_time
-        elif isinstance(max_time, str):
-            self.max_time = convert_to_seconds(max_time)
-        else:
-            raise TypeError("max_time must be a float, int, or string. Received a {}.".format(type(max_time)))
-
-        if max_pipelines:
-            if not max_iterations:
-                max_iterations = max_pipelines
-            logger.warning("`max_pipelines` will be deprecated in the next release. Use `max_iterations` instead.")
-
+        if not isinstance(max_time, (int, float, str, type(None))):
+            raise TypeError(f"Parameter max_time must be a float, int, string or None. Received {type(max_time)} with value {str(max_time)}..")
+        if isinstance(max_time, (int, float)) and max_time < 0:
+            raise ValueError(f"Parameter max_time must be None or non-negative. Received {max_time}.")
+        if max_batches is not None and max_batches < 0:
+            raise ValueError(f"Parameter max_batches must be None or non-negative. Received {max_batches}.")
+        if max_iterations is not None and max_iterations < 0:
+            raise ValueError(f"Parameter max_iterations must be None or non-negative. Received {max_iterations}.")
+        self.max_time = convert_to_seconds(max_time) if isinstance(max_time, str) else max_time
         self.max_iterations = max_iterations
-        if not self.max_iterations and not self.max_time and not _max_batches:
-            self.max_iterations = 5
-            logger.info("Using default limit of max_iterations=5.\n")
+        self.max_batches = max_batches
+        self._pipelines_per_batch = _pipelines_per_batch
+        if not self.max_iterations and not self.max_time and not self.max_batches:
+            self.max_batches = 1
+            logger.info("Using default limit of max_batches=1.\n")
 
         if patience and (not isinstance(patience, int) or patience < 0):
             raise ValueError("patience value must be a positive integer. Received {} instead".format(patience))
@@ -204,7 +231,8 @@ class AutoMLSearch:
         self.tolerance = tolerance or 0.0
         self._results = {
             'pipeline_results': {},
-            'search_order': []
+            'search_order': [],
+            'errors': []
         }
         self.random_state = get_random_state(random_state)
         self.n_jobs = n_jobs
@@ -221,29 +249,24 @@ class AutoMLSearch:
         self.allowed_model_families = allowed_model_families
         self._automl_algorithm = None
         self._start = None
-        self._baseline_cv_score = None
-
-        if _max_batches is not None and _max_batches <= 0:
-            raise ValueError(f"Parameter max batches must be None or non-negative. Received {_max_batches}.")
-        self._max_batches = _max_batches
-        # This is the default value for IterativeAlgorithm - setting this explicitly makes sure that
-        # the behavior of max_batches does not break if IterativeAlgorithm is changed.
-        self._pipelines_per_batch = 5
+        self._baseline_cv_scores = {}
 
         self._validate_problem_type()
+        self.problem_configuration = self._validate_problem_configuration(problem_configuration)
 
     def _validate_objective(self, objective):
         non_core_objectives = get_non_core_objectives()
         if isinstance(objective, type):
             if objective in non_core_objectives:
                 raise ValueError(f"{objective.name.lower()} is not allowed in AutoML! "
-                                 "Use evalml.objectives.utils.get_core_objective_names()"
+                                 "Use evalml.objectives.utils.get_core_objective_names() "
                                  "to get all objective names allowed in automl.")
             return objective()
         return objective
 
     @property
     def data_check_results(self):
+        """If there are data checks, return any error messages that are found"""
         return self._data_check_results
 
     def __str__(self):
@@ -263,6 +286,7 @@ class AutoMLSearch:
             f"Objective: {get_objective(self.objective).name}\n"
             f"Max Time: {self.max_time}\n"
             f"Max Iterations: {self.max_iterations}\n"
+            f"Max Batches: {self.max_batches}\n"
             f"Allowed Pipelines: \n{_print_list(self.allowed_pipelines or [])}\n"
             f"Patience: {self.patience}\n"
             f"Tolerance: {self.tolerance}\n"
@@ -284,6 +308,14 @@ class AutoMLSearch:
 
         return search_desc + rankings_desc
 
+    def _validate_problem_configuration(self, problem_configuration=None):
+        if self.problem_type in [ProblemTypes.TIME_SERIES_REGRESSION]:
+            required_parameters = {'gap', 'max_delay'}
+            if not problem_configuration or not all(p in problem_configuration for p in required_parameters):
+                raise ValueError("user_parameters must be a dict containing values for at least the gap and max_delay "
+                                 f"parameters. Received {problem_configuration}.")
+        return problem_configuration or {}
+
     def _validate_data_checks(self, data_checks):
         """Validate data_checks parameter.
 
@@ -337,16 +369,32 @@ class AutoMLSearch:
             else:
                 leading_char = ""
 
-    def search(self, X, y, data_checks="auto", feature_types=None, show_iteration_plot=True):
+    def _set_data_split(self, X):
+        """Sets the data split method for AutoMLSearch
+
+        Arguments:
+            X (DataFrame): Input dataframe to split
+        """
+        if self.problem_type == ProblemTypes.REGRESSION:
+            default_data_split = KFold(n_splits=3, random_state=self.random_state, shuffle=True)
+        elif self.problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
+            default_data_split = StratifiedKFold(n_splits=3, random_state=self.random_state, shuffle=True)
+        elif self.problem_type in [ProblemTypes.TIME_SERIES_REGRESSION]:
+            default_data_split = TimeSeriesSplit(n_splits=3, gap=self.problem_configuration['gap'],
+                                                 max_delay=self.problem_configuration['max_delay'])
+
+        if X.shape[0] > self._LARGE_DATA_ROW_THRESHOLD:
+            default_data_split = TrainingValidationSplit(test_size=self._LARGE_DATA_PERCENT_VALIDATION, shuffle=True)
+
+        self.data_split = self.data_split or default_data_split
+
+    def search(self, X, y, data_checks="auto", show_iteration_plot=True):
         """Find the best pipeline for the data set.
 
         Arguments:
-            X (pd.DataFrame): the input training data of shape [n_samples, n_features]
+            X (pd.DataFrame, ww.DataTable): The input training data of shape [n_samples, n_features]
 
-            y (pd.Series): the target training data of length [n_samples]
-
-            feature_types (list, optional): list of feature types, either numerical or categorical.
-                Categorical features will automatically be encoded
+            y (pd.Series, ww.DataColumn): The target training data of length [n_samples]
 
             show_iteration_plot (boolean, True): Shows an iteration vs. score plot in Jupyter notebook.
                 Disabled by default in non-Jupyter enviroments.
@@ -366,48 +414,53 @@ class AutoMLSearch:
             except NameError:
                 show_iteration_plot = False
 
-        # make everything pandas objects
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
+        # make everything ww objects
+        if not isinstance(X, ww.DataTable):
+            logger.warning("`X` passed was not a DataTable. EvalML will try to convert the input as a Woodwork DataTable and types will be inferred. To control this behavior, please pass in a Woodwork DataTable instead.")
+            X = _convert_to_woodwork_structure(X)
 
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
+        text_column_vals = X.select('natural_language')
+        text_columns = list(text_column_vals.to_dataframe().columns)
+        if len(text_columns) == 0:
+            text_columns = None
 
-        # Set the default data splitter
-        if self.problem_type == ProblemTypes.REGRESSION:
-            default_data_split = KFold(n_splits=3, random_state=self.random_state)
-        elif self.problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
-            default_data_split = StratifiedKFold(n_splits=3, random_state=self.random_state)
+        if not isinstance(y, ww.DataColumn):
+            logger.warning("`y` passed was not a DataColumn. EvalML will try to convert the input as a Woodwork DataTable and types will be inferred. To control this behavior, please pass in a Woodwork DataTable instead.")
+            y = _convert_to_woodwork_structure(y)
 
-        if X.shape[0] > self._LARGE_DATA_ROW_THRESHOLD:
-            default_data_split = TrainingValidationSplit(test_size=self._LARGE_DATA_PERCENT_VALIDATION)
-
-        self.data_split = self.data_split or default_data_split
+        self._set_data_split(X)
 
         data_checks = self._validate_data_checks(data_checks)
-        data_check_results = data_checks.validate(X, y)
-
-        if len(data_check_results) > 0:
-            self._data_check_results = data_check_results
-            for message in self._data_check_results:
-                if message.message_type == DataCheckMessageType.WARNING:
-                    logger.warning(message)
-                elif message.message_type == DataCheckMessageType.ERROR:
-                    logger.error(message)
-            if any([message.message_type == DataCheckMessageType.ERROR for message in self._data_check_results]):
-                raise ValueError("Data checks raised some warnings and/or errors. Please see `self.data_check_results` for more information or pass data_checks='disabled' to search() to disable data checking.")
-
+        self._data_check_results = data_checks.validate(_convert_woodwork_types_wrapper(X.to_dataframe()), _convert_woodwork_types_wrapper(y.to_series()))
+        for message in self._data_check_results["warnings"]:
+            logger.warning(message)
+        for message in self._data_check_results["errors"]:
+            logger.error(message)
+        if self._data_check_results["errors"]:
+            raise ValueError("Data checks raised some warnings and/or errors. Please see `self.data_check_results` for more information or pass data_checks='disabled' to search() to disable data checking.")
         if self.allowed_pipelines is None:
             logger.info("Generating pipelines to search over...")
             allowed_estimators = get_estimators(self.problem_type, self.allowed_model_families)
             logger.debug(f"allowed_estimators set to {[estimator.name for estimator in allowed_estimators]}")
-            self.allowed_pipelines = [make_pipeline(X, y, estimator, self.problem_type) for estimator in allowed_estimators]
+            self.allowed_pipelines = [make_pipeline(X, y, estimator, self.problem_type, text_columns=text_columns) for estimator in allowed_estimators]
 
         if self.allowed_pipelines == []:
             raise ValueError("No allowed pipelines to search")
-        if self._max_batches and self.max_iterations is None:
-            self.max_iterations = 1 + len(self.allowed_pipelines) + (self._pipelines_per_batch * (self._max_batches - 1))
 
+        run_ensembling = self.ensembling
+        if run_ensembling and len(self.allowed_pipelines) == 1:
+            logger.warning("Ensembling was set to True, but the number of unique pipelines is one, so ensembling will not run.")
+            run_ensembling = False
+
+        if self.max_batches and self.max_iterations is None:
+            if run_ensembling:
+                ensemble_nth_batch = len(self.allowed_pipelines) + 1
+                num_ensemble_batches = (self.max_batches - 1) // ensemble_nth_batch
+                self.max_iterations = (1 + len(self.allowed_pipelines) +
+                                       self._pipelines_per_batch * (self.max_batches - 1 - num_ensemble_batches) +
+                                       num_ensemble_batches)
+            else:
+                self.max_iterations = 1 + len(self.allowed_pipelines) + (self._pipelines_per_batch * (self.max_batches - 1))
         self.allowed_model_families = list(set([p.model_family for p in (self.allowed_pipelines)]))
 
         logger.debug(f"allowed_pipelines set to {[pipeline.name for pipeline in self.allowed_pipelines]}")
@@ -417,17 +470,22 @@ class AutoMLSearch:
             max_iterations=self.max_iterations,
             allowed_pipelines=self.allowed_pipelines,
             tuner_class=self.tuner_class,
+            text_columns=text_columns,
             random_state=self.random_state,
             n_jobs=self.n_jobs,
             number_features=X.shape[1],
-            pipelines_per_batch=self._pipelines_per_batch
+            pipelines_per_batch=self._pipelines_per_batch,
+            ensembling=run_ensembling,
+            pipeline_params=self.problem_configuration
         )
 
         log_title(logger, "Beginning pipeline search")
         logger.info("Optimizing for %s. " % self.objective.name)
         logger.info("{} score is better.\n".format('Greater' if self.objective.greater_is_better else 'Lower'))
 
-        if self.max_iterations is not None:
+        if self.max_batches is not None:
+            logger.info(f"Searching up to {self.max_batches} batches for a total of {self.max_iterations} pipelines. ")
+        elif self.max_iterations is not None:
             logger.info("Searching up to %s pipelines. " % self.max_iterations)
         if self.max_time is not None:
             logger.info("Will stop searching for new pipelines after %d seconds.\n" % self.max_time)
@@ -467,7 +525,10 @@ class AutoMLSearch:
                     desc = desc[:self._MAX_NAME_LEN - 3] + "..."
                 desc = desc.ljust(self._MAX_NAME_LEN)
 
-                update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations, self._start)
+                if self.max_batches:
+                    update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations, self._start, self._automl_algorithm.batch_number)
+                else:
+                    update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations, self._start)
 
                 evaluation_results = self._evaluate(pipeline, X, y)
                 score = evaluation_results['cv_score_mean']
@@ -527,11 +588,11 @@ class AutoMLSearch:
 
     def _validate_problem_type(self):
         for obj in self.additional_objectives:
-            if obj.problem_type != self.problem_type:
+            if not obj.is_defined_for_problem_type(self.problem_type):
                 raise ValueError("Additional objective {} is not compatible with a {} problem.".format(obj.name, self.problem_type.value))
 
         for pipeline in self.allowed_pipelines or []:
-            if not pipeline.problem_type == self.problem_type:
+            if pipeline.problem_type != self.problem_type:
                 raise ValueError("Given pipeline {} is not compatible with problem_type {}.".format(pipeline.name, self.problem_type.value))
 
     def _add_baseline_pipelines(self, X, y):
@@ -552,7 +613,7 @@ class AutoMLSearch:
             baseline = ModeBaselineBinaryPipeline(parameters={})
         elif self.problem_type == ProblemTypes.MULTICLASS:
             baseline = ModeBaselineMulticlassPipeline(parameters={})
-        elif self.problem_type == ProblemTypes.REGRESSION:
+        else:
             baseline = MeanBaselineRegressionPipeline(parameters={})
 
         pipelines = [baseline]
@@ -569,10 +630,10 @@ class AutoMLSearch:
                 desc = desc.ljust(self._MAX_NAME_LEN)
 
                 update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations,
-                                self._start)
+                                self._start, 1)
 
                 baseline_results = self._compute_cv_scores(baseline, X, y)
-                self._baseline_cv_score = baseline_results["cv_score_mean"]
+                self._baseline_cv_scores = self._get_mean_cv_scores_for_all_objectives(baseline_results["cv_data"])
                 self._add_result(trained_pipeline=baseline,
                                  parameters=baseline.parameters,
                                  training_time=baseline_results['training_time'],
@@ -585,17 +646,38 @@ class AutoMLSearch:
 
         return False
 
+    @staticmethod
+    def _get_mean_cv_scores_for_all_objectives(cv_data):
+        scores = defaultdict(int)
+        objective_names = set([name.lower() for name in get_all_objective_names()])
+        n_folds = len(cv_data)
+        for fold_data in cv_data:
+            for field, value in fold_data['all_objective_scores'].items():
+                if field.lower() in objective_names:
+                    scores[field] += value
+        return {objective_name: float(score) / n_folds for objective_name, score in scores.items()}
+
     def _compute_cv_scores(self, pipeline, X, y):
         start = time.time()
         cv_data = []
         logger.info("\tStarting cross validation")
-        for i, (train, test) in enumerate(self.data_split.split(X, y)):
+        X = _convert_to_woodwork_structure(X)
+        y = _convert_to_woodwork_structure(y)
+
+        X_pd = _convert_woodwork_types_wrapper(X.to_dataframe())
+        y_pd = _convert_woodwork_types_wrapper(y.to_series())
+        for i, (train, test) in enumerate(self.data_split.split(X_pd, y_pd)):
+
+            if pipeline.model_family == ModelFamily.ENSEMBLE and i > 0:
+                # Stacked ensembles do CV internally, so we do not run CV here for performance reasons.
+                logger.debug(f"Skipping fold {i} because CV for stacked ensembles is not supported.")
+                break
             logger.debug(f"\t\tTraining and scoring on fold {i}")
             X_train, X_test = X.iloc[train], X.iloc[test]
             y_train, y_test = y.iloc[train], y.iloc[test]
             if self.problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
-                diff_train = set(np.setdiff1d(y, y_train))
-                diff_test = set(np.setdiff1d(y, y_test))
+                diff_train = set(np.setdiff1d(y.to_series(), y_train.to_series()))
+                diff_test = set(np.setdiff1d(y.to_series(), y_test.to_series()))
                 diff_string = f"Missing target values in the training set after data split: {diff_train}. " if diff_train else ""
                 diff_string += f"Missing target values in the test set after data split: {diff_test}." if diff_test else ""
                 if diff_string:
@@ -605,13 +687,13 @@ class AutoMLSearch:
             try:
                 X_threshold_tuning = None
                 y_threshold_tuning = None
-                if self.optimize_thresholds and self.objective.problem_type == ProblemTypes.BINARY and self.objective.can_optimize_threshold:
+                if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold:
                     X_train, X_threshold_tuning, y_train, y_threshold_tuning = train_test_split(X_train, y_train, test_size=0.2, random_state=self.random_state)
-                cv_pipeline = pipeline.clone()
+                cv_pipeline = pipeline.clone(pipeline.random_state)
                 logger.debug(f"\t\t\tFold {i}: starting training")
                 cv_pipeline.fit(X_train, y_train)
                 logger.debug(f"\t\t\tFold {i}: finished training")
-                if self.objective.problem_type == ProblemTypes.BINARY:
+                if self.objective.is_defined_for_problem_type(ProblemTypes.BINARY):
                     cv_pipeline.threshold = 0.5
                     if self.optimize_thresholds and self.objective.can_optimize_threshold:
                         logger.debug(f"\t\t\tFold {i}: Optimizing threshold for {self.objective.name}")
@@ -627,36 +709,29 @@ class AutoMLSearch:
                 logger.debug(f"\t\t\tFold {i}: {self.objective.name} score: {scores[self.objective.name]:.3f}")
                 score = scores[self.objective.name]
             except Exception as e:
+
+                if self.error_callback is not None:
+                    self.error_callback(exception=e, traceback=traceback.format_tb(sys.exc_info()[2]), automl=self,
+                                        fold_num=i, pipeline=pipeline)
                 if isinstance(e, PipelineScoreError):
-                    logger.info(f"\t\t\tFold {i}: Encountered an error scoring the following objectives: {', '.join(e.exceptions)}.")
-                    logger.info(f"\t\t\tFold {i}: The scores for these objectives will be replaced with nan.")
-                    logger.info(f"\t\t\tFold {i}: Please check {logger.handlers[1].baseFilename} for the current hyperparameters and stack trace.")
-                    logger.debug(f"\t\t\tFold {i}: Hyperparameters:\n\t{pipeline.hyperparameters}")
-                    logger.debug(f"\t\t\tFold {i}: Exception during automl search: {str(e)}")
                     nan_scores = {objective: np.nan for objective in e.exceptions}
                     scores = {**nan_scores, **e.scored_successfully}
                     scores = OrderedDict({o.name: scores[o.name] for o in [self.objective] + self.additional_objectives})
                     score = scores[self.objective.name]
                 else:
-                    logger.info(f"\t\t\tFold {i}: Encountered an error.")
-                    logger.info(f"\t\t\tFold {i}: All scores will be replaced with nan.")
-                    logger.info(f"\t\t\tFold {i}: Please check {logger.handlers[1].baseFilename} for the current hyperparameters and stack trace.")
-                    logger.debug(f"\t\t\tFold {i}: Hyperparameters:\n\t{pipeline.hyperparameters}")
-                    logger.debug(f"\t\t\tFold {i}: Exception during automl search: {str(e)}")
                     score = np.nan
                     scores = OrderedDict(zip([n.name for n in self.additional_objectives], [np.nan] * len(self.additional_objectives)))
 
             ordered_scores = OrderedDict()
             ordered_scores.update({self.objective.name: score})
             ordered_scores.update(scores)
-            ordered_scores.update({"# Training": len(y_train)})
-            ordered_scores.update({"# Testing": len(y_test)})
+            ordered_scores.update({"# Training": y_train.shape[0]})
+            ordered_scores.update({"# Testing": y_test.shape[0]})
 
             evaluation_entry = {"all_objective_scores": ordered_scores, "score": score, 'binary_classification_threshold': None}
             if isinstance(cv_pipeline, BinaryClassificationPipeline) and cv_pipeline.threshold is not None:
                 evaluation_entry['binary_classification_threshold'] = cv_pipeline.threshold
             cv_data.append(evaluation_entry)
-
         training_time = time.time() - start
         cv_scores = pd.Series([fold['score'] for fold in cv_data])
         cv_score_mean = cv_scores.mean()
@@ -665,17 +740,29 @@ class AutoMLSearch:
 
     def _add_result(self, trained_pipeline, parameters, training_time, cv_data, cv_scores):
         cv_score = cv_scores.mean()
-        percent_better = self.objective.calculate_percent_difference(cv_score, self._baseline_cv_score)
-        # calculate high_variance_cv
-        # if the coefficient of variance is greater than .2
-        with warnings.catch_warnings():
-            warnings.simplefilter('ignore')
-            high_variance_cv = (cv_scores.std() / cv_scores.mean()) > .2
+
+        percent_better_than_baseline = {}
+        mean_cv_all_objectives = self._get_mean_cv_scores_for_all_objectives(cv_data)
+        for obj_name in mean_cv_all_objectives:
+            objective_class = get_objective(obj_name)
+            # In the event add_to_rankings is called before search _baseline_cv_scores will be empty so we will return
+            # nan for the base score.
+            percent_better = objective_class.calculate_percent_difference(mean_cv_all_objectives[obj_name],
+                                                                          self._baseline_cv_scores.get(obj_name, np.nan))
+            percent_better_than_baseline[obj_name] = percent_better
 
         pipeline_name = trained_pipeline.name
         pipeline_summary = trained_pipeline.summary
         pipeline_id = len(self._results['pipeline_results'])
 
+        high_variance_cv_check = HighVarianceCVDataCheck(threshold=0.2)
+        high_variance_cv_check_results = high_variance_cv_check.validate(pipeline_name=pipeline_name, cv_scores=cv_scores)
+        high_variance_cv = False
+
+        if high_variance_cv_check_results["warnings"]:
+            logger.warning(high_variance_cv_check_results["warnings"][0]["message"])
+            high_variance_cv = True
+
         self._results['pipeline_results'][pipeline_id] = {
             "id": pipeline_id,
             "pipeline_name": pipeline_name,
@@ -686,7 +773,8 @@ class AutoMLSearch:
             "high_variance_cv": high_variance_cv,
             "training_time": training_time,
             "cv_data": cv_data,
-            "percent_better_than_baseline": percent_better,
+            "percent_better_than_baseline_all_objectives": percent_better_than_baseline,
+            "percent_better_than_baseline": percent_better_than_baseline[self.objective.name],
             "validation_score": cv_scores[0]
         }
         self._results['search_order'].append(pipeline_id)
@@ -704,7 +792,6 @@ class AutoMLSearch:
                          training_time=evaluation_results['training_time'],
                          cv_data=evaluation_results['cv_data'],
                          cv_scores=evaluation_results['cv_scores'])
-
         logger.debug('Adding results complete')
         return evaluation_results
 
@@ -750,16 +837,12 @@ class AutoMLSearch:
         log_subtitle(logger, "Training")
         logger.info("Training for {} problems.".format(pipeline.problem_type))
 
-        if self.optimize_thresholds and self.objective.problem_type == ProblemTypes.BINARY and self.objective.can_optimize_threshold:
+        if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold:
             logger.info("Objective to optimize binary classification pipeline thresholds for: {}".format(self.objective))
 
         logger.info("Total training time (including CV): %.1f seconds" % pipeline_results["training_time"])
         log_subtitle(logger, "Cross Validation", underline="-")
 
-        if pipeline_results["high_variance_cv"]:
-            logger.warning("High variance within cross validation scores. " +
-                           "Model may not perform as estimated on unseen data.")
-
         all_objective_scores = [fold["all_objective_scores"] for fold in pipeline_results["cv_data"]]
         all_objective_scores = pd.DataFrame(all_objective_scores)
 
@@ -798,8 +881,7 @@ class AutoMLSearch:
         if not isinstance(y, pd.Series):
             y = pd.Series(y)
 
-        if not self.has_searched:
-            raise RuntimeError("Please run automl search before calling `add_to_rankings()`")
+        self._set_data_split(X)
 
         pipeline_rows = self.full_rankings[self.full_rankings['pipeline_name'] == pipeline.name]
         for parameter in pipeline_rows['parameters']:
