@@ -1,4 +1,6 @@
 from .data_check import DataCheck
+from .data_check_message_code import DataCheckMessageCode
+
 from .data_checks import AutoMLDataChecks, DataChecks
 from .data_check_message import DataCheckMessage, DataCheckWarning, DataCheckError
 from .data_check_message_type import DataCheckMessageType
@@ -7,7 +9,8 @@ from .utils import EmptyDataChecks
 from .invalid_targets_data_check import InvalidTargetDataCheck
 from .highly_null_data_check import HighlyNullDataCheck
 from .id_columns_data_check import IDColumnsDataCheck
-from .label_leakage_data_check import LabelLeakageDataCheck
+from .target_leakage_data_check import TargetLeakageDataCheck
 from .outliers_data_check import OutliersDataCheck
 from .no_variance_data_check import NoVarianceDataCheck
 from .class_imbalance_data_check import ClassImbalanceDataCheck
+from .high_variance_cv_data_check import HighVarianceCVDataCheck
