@@ -10,11 +10,11 @@ from evalml.problem_types import ProblemTypes
 class BinaryClassificationObjective(ObjectiveBase):
     """Base class for all binary classification objectives.
 
-    problem_type (ProblemTypes): Type of problem this objective is. Set to ProblemTypes.BINARY.
+    problem_types (list(ProblemType)): List of problem types that this objective is defined for. Set to [ProblemTypes.BINARY].
     can_optimize_threshold (bool): Determines if threshold used by objective can be optimized or not.
     """
 
-    problem_type = ProblemTypes.BINARY
+    problem_types = [ProblemTypes.BINARY]
 
     @property
     def can_optimize_threshold(cls):
