@@ -1,6 +1,7 @@
 from .components import (
     Estimator,
     OneHotEncoder,
+    TargetEncoder,
     SimpleImputer,
     PerColumnImputer,
     StandardScaler,
@@ -22,7 +23,10 @@ from .components import (
     ExtraTreesClassifier,
     ExtraTreesRegressor,
     DecisionTreeClassifier,
-    DecisionTreeRegressor
+    DecisionTreeRegressor,
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor,
+    DelayedFeatureTransformer
 )
 
 from .pipeline_base import PipelineBase
@@ -42,3 +46,5 @@ from .regression import (
     BaselineRegressionPipeline,
     MeanBaselineRegressionPipeline
 )
+
+from .time_series_regression_pipeline import TimeSeriesRegressionPipeline
