@@ -47,6 +47,11 @@ class SimpleImputer(Transformer):
         """
         X = _convert_to_woodwork_structure(X)
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
+
+        # Convert all bool dtypes to category for fitting
+        if (X.dtypes == bool).all():
+            X = X.astype('category')
+
         # Convert None to np.nan, since None cannot be properly handled
         X = X.fillna(value=np.nan)
 
@@ -70,6 +75,9 @@ class SimpleImputer(Transformer):
         # Convert None to np.nan, since None cannot be properly handled
         X = X.fillna(value=np.nan)
 
+        # Return early since bool dtype doesn't support nans and sklearn errors if all cols are bool
+        if (X.dtypes == bool).all():
+            return X
         X_null_dropped = X.copy()
         X_null_dropped.drop(self._all_null_cols, axis=1, errors='ignore', inplace=True)
         category_cols = X_null_dropped.select_dtypes(include=['category']).columns
