@@ -1,6 +1,8 @@
-import pandas as pd
-
 from evalml.pipelines.components.transformers import Transformer
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper
+)
 
 
 class DropNullColumns(Transformer):
@@ -28,9 +30,9 @@ class DropNullColumns(Transformer):
 
     def fit(self, X, y=None):
         pct_null_threshold = self.parameters["pct_null_threshold"]
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
-        percent_null = X.isnull().mean()
+        X_t = _convert_to_woodwork_structure(X)
+        X_t = _convert_woodwork_types_wrapper(X_t.to_dataframe())
+        percent_null = X_t.isnull().mean()
         if pct_null_threshold == 0.0:
             null_cols = percent_null[percent_null > 0]
         else:
@@ -48,7 +50,6 @@ class DropNullColumns(Transformer):
         Returns:
             pd.DataFrame: Transformed X
         """
-
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
-        return X.drop(columns=self._cols_to_drop, axis=1)
+        X_t = _convert_to_woodwork_structure(X)
+        X_t = _convert_woodwork_types_wrapper(X_t.to_dataframe())
+        return X_t.drop(columns=self._cols_to_drop, axis=1)
