@@ -1,12 +1,17 @@
 import string
 
+import featuretools as ft
+import nlp_primitives
 import pandas as pd
 
 from evalml.pipelines.components.transformers.preprocessing import (
     LSA,
     TextTransformer
 )
-from evalml.utils import import_or_raise
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper
+)
 
 
 class TextFeaturizer(TextTransformer):
@@ -22,12 +27,9 @@ class TextFeaturizer(TextTransformer):
             random_state (int, np.random.RandomState): Seed for the random number generator.
 
         """
-        self._ft = import_or_raise("featuretools", error_msg="Package featuretools is not installed. Please install using `pip install featuretools[nlp_primitives].`")
-        self._nlp_primitives = import_or_raise("nlp_primitives", error_msg="Package nlp_primitives is not installed. Please install using `pip install featuretools[nlp_primitives].`")
-        self._trans = [self._nlp_primitives.DiversityScore,
-                       self._nlp_primitives.MeanCharactersPerWord,
-                       self._nlp_primitives.PartOfSpeechCount,
-                       self._nlp_primitives.PolarityScore]
+        self._trans = [nlp_primitives.DiversityScore,
+                       nlp_primitives.MeanCharactersPerWord,
+                       nlp_primitives.PolarityScore]
         self._features = None
         self._lsa = LSA(text_columns=text_columns, random_state=random_state)
         super().__init__(text_columns=text_columns,
@@ -55,7 +57,7 @@ class TextFeaturizer(TextTransformer):
         X_text.rename(columns=str, inplace=True)
         all_text_variable_types = {col_name: 'text' for col_name in X_text.columns}
 
-        es = self._ft.EntitySet()
+        es = ft.EntitySet()
         es.entity_from_dataframe(entity_id='X', dataframe=X_text, index='index', make_index=True,
                                  variable_types=all_text_variable_types)
         return es
@@ -64,7 +66,7 @@ class TextFeaturizer(TextTransformer):
         """Fits component to data
 
         Arguments:
-            X (pd.DataFrame or np.array): the input training data of shape [n_samples, n_features]
+            X (pd.DataFrame or np.ndarray): the input training data of shape [n_samples, n_features]
             y (pd.Series, optional): the target training labels of length [n_samples]
 
         Returns:
@@ -72,15 +74,15 @@ class TextFeaturizer(TextTransformer):
         """
         if len(self._all_text_columns) == 0:
             return self
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
+        X = _convert_to_woodwork_structure(X)
+        X = _convert_woodwork_types_wrapper(X.to_dataframe())
 
         text_columns = self._get_text_columns(X)
         es = self._make_entity_set(X, text_columns)
-        self._features = self._ft.dfs(entityset=es,
-                                      target_entity='X',
-                                      trans_primitives=self._trans,
-                                      features_only=True)
+        self._features = ft.dfs(entityset=es,
+                                target_entity='X',
+                                trans_primitives=self._trans,
+                                features_only=True)
         self._lsa.fit(X)
         return self
 
@@ -94,14 +96,14 @@ class TextFeaturizer(TextTransformer):
         Returns:
             pd.DataFrame: Transformed X
         """
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
+        X = _convert_to_woodwork_structure(X)
+        X = _convert_woodwork_types_wrapper(X.to_dataframe())
         if self._features is None or len(self._features) == 0:
             return X
 
         text_columns = self._get_text_columns(X)
         es = self._make_entity_set(X, text_columns)
-        X_nlp_primitives = self._ft.calculate_feature_matrix(features=self._features, entityset=es)
+        X_nlp_primitives = ft.calculate_feature_matrix(features=self._features, entityset=es)
         if X_nlp_primitives.isnull().any().any():
             X_nlp_primitives.fillna(0, inplace=True)
 
