@@ -1,9 +1,8 @@
 import pandas as pd
+from pandas.api.types import is_numeric_dtype
 
 from .problem_types import ProblemTypes
 
-from evalml.utils.gen_utils import numeric_dtypes
-
 
 def handle_problem_types(problem_type):
     """Handles problem_type by either returning the ProblemTypes or converting from a str.
@@ -46,7 +45,7 @@ def detect_problem_type(y):
         raise ValueError("Less than 2 classes detected! Target unusable for modeling")
     if num_classes == 2:
         return ProblemTypes.BINARY
-    if y.dtype in numeric_dtypes:
+    if is_numeric_dtype(y.dtype):
         if (num_classes > 10):
             return ProblemTypes.REGRESSION
     return ProblemTypes.MULTICLASS
