@@ -86,16 +86,6 @@ def test_max_iterations(X_y_binary):
     assert len(automl.full_rankings) == max_iterations
 
 
-def test_max_pipelines_deprecation(caplog):
-    AutoMLSearch(problem_type='binary', max_pipelines=5)
-    assert "`max_pipelines` will be deprecated in the next release. Use `max_iterations` instead." in caplog.text
-
-    caplog.clear()
-    search = AutoMLSearch(problem_type='binary', max_iterations=10, max_pipelines=5)
-    assert "`max_pipelines` will be deprecated in the next release. Use `max_iterations` instead." in caplog.text
-    assert search.max_iterations == 10
-
-
 def test_recall_error(X_y_binary):
     X, y = X_y_binary
     # Recall is a valid objective but it's not allowed in AutoML so a ValueError is expected
@@ -307,7 +297,7 @@ def test_max_time_units():
     with pytest.raises(AssertionError, match="Invalid unit. Units must be hours, mins, or seconds. Received 'year'"):
         AutoMLSearch(problem_type='binary', objective='F1', max_time='30 years')
 
-    with pytest.raises(TypeError, match="max_time must be a float, int, or string. Received a <class 'tuple'>."):
+    with pytest.raises(TypeError, match="Parameter max_time must be a float, int, string or None. Received <class 'tuple'> with value \\(30, 'minutes'\\)."):
         AutoMLSearch(problem_type='binary', objective='F1', max_time=(30, 'minutes'))
 
 
