@@ -13,19 +13,6 @@ def test_model_family():
     assert ElasticNetClassifier.model_family == ModelFamily.LINEAR_MODEL
 
 
-def test_en_parameters():
-    clf = ElasticNetClassifier(alpha=0.75, l1_ratio=0.5, random_state=2)
-    expected_parameters = {
-        "alpha": 0.75,
-        "l1_ratio": 0.5,
-        'max_iter': 1000,
-        'n_jobs': -1,
-        'penalty': 'elasticnet',
-        'loss': 'log'
-    }
-    assert clf.parameters == expected_parameters
-
-
 def test_problem_types():
     assert set(ElasticNetClassifier.supported_problem_types) == {ProblemTypes.BINARY, ProblemTypes.MULTICLASS}
 
