@@ -2,13 +2,16 @@ import numpy as np
 import pandas as pd
 import pytest
 
-from evalml.data_checks import DefaultDataChecks, EmptyDataChecks
-from evalml.data_checks.data_check import DataCheck
-from evalml.data_checks.data_check_message import (
+from evalml.data_checks import (
+    AutoMLDataChecks,
+    DataCheck,
     DataCheckError,
-    DataCheckWarning
+    DataCheckMessageCode,
+    DataChecks,
+    DataCheckWarning,
+    DefaultDataChecks,
+    EmptyDataChecks
 )
-from evalml.data_checks.data_checks import AutoMLDataChecks, DataChecks
 from evalml.exceptions import DataCheckInitError
 
 
@@ -17,41 +20,65 @@ def test_data_checks(X_y_binary):
 
     class MockDataCheck(DataCheck):
         def validate(self, X, y):
-            return []
+            return {"warnings": [], "errors": []}
 
     class MockDataCheckWarning(DataCheck):
         def validate(self, X, y):
-            return [DataCheckWarning("warning one", self.name)]
+            return {"warnings": [DataCheckWarning(message="warning one", data_check_name=self.name, message_code=None).to_dict()], "errors": []}
 
     class MockDataCheckError(DataCheck):
         def validate(self, X, y):
-            return [DataCheckError("error one", self.name)]
+            return {"warnings": [], "errors": [DataCheckError(message="error one", data_check_name=self.name, message_code=None).to_dict()]}
 
     class MockDataCheckErrorAndWarning(DataCheck):
         def validate(self, X, y):
-            return [DataCheckError("error two", self.name), DataCheckWarning("warning two", self.name)]
+            return {"warnings": [DataCheckWarning(message="warning two", data_check_name=self.name, message_code=None).to_dict()],
+                    "errors": [DataCheckError(message="error two", data_check_name=self.name, message_code=None).to_dict()]}
 
     data_checks_list = [MockDataCheck, MockDataCheckWarning, MockDataCheckError, MockDataCheckErrorAndWarning]
     data_checks = DataChecks(data_checks=data_checks_list)
-    assert data_checks.validate(X, y) == [DataCheckWarning("warning one", "MockDataCheckWarning"),
-                                          DataCheckError("error one", "MockDataCheckError"),
-                                          DataCheckError("error two", "MockDataCheckErrorAndWarning"),
-                                          DataCheckWarning("warning two", "MockDataCheckErrorAndWarning")]
+    assert data_checks.validate(X, y) == {
+        "warnings": [DataCheckWarning(message="warning one", data_check_name="MockDataCheckWarning").to_dict(),
+                     DataCheckWarning(message="warning two", data_check_name="MockDataCheckErrorAndWarning").to_dict()],
+        "errors": [DataCheckError(message="error one", data_check_name="MockDataCheckError").to_dict(),
+                   DataCheckError(message="error two", data_check_name="MockDataCheckErrorAndWarning").to_dict()]
+    }
 
 
 def test_empty_data_checks(X_y_binary):
     X, y = X_y_binary
     data_checks = EmptyDataChecks()
-    assert data_checks.validate(X, y) == []
+    assert data_checks.validate(X, y) == {"warnings": [], "errors": []}
 
 
-messages = [DataCheckWarning("Column 'all_null' is 95.0% or more null", "HighlyNullDataCheck"),
-            DataCheckWarning("Column 'also_all_null' is 95.0% or more null", "HighlyNullDataCheck"),
-            DataCheckWarning("Column 'id' is 100.0% or more likely to be an ID column", "IDColumnsDataCheck"),
-            DataCheckError("1 row(s) (20.0%) of target values are null", "InvalidTargetDataCheck"),
-            DataCheckError("lots_of_null has 1 unique value.", "NoVarianceDataCheck"),
-            DataCheckError("all_null has 0 unique value.", "NoVarianceDataCheck"),
-            DataCheckError("also_all_null has 0 unique value.", "NoVarianceDataCheck")]
+messages = [DataCheckWarning(message="Column 'all_null' is 95.0% or more null",
+                             data_check_name="HighlyNullDataCheck",
+                             message_code=DataCheckMessageCode.HIGHLY_NULL,
+                             details={"column": "all_null"}).to_dict(),
+            DataCheckWarning(message="Column 'also_all_null' is 95.0% or more null",
+                             data_check_name="HighlyNullDataCheck",
+                             message_code=DataCheckMessageCode.HIGHLY_NULL,
+                             details={"column": "also_all_null"}).to_dict(),
+            DataCheckWarning(message="Column 'id' is 100.0% or more likely to be an ID column",
+                             data_check_name="IDColumnsDataCheck",
+                             message_code=DataCheckMessageCode.HAS_ID_COLUMN,
+                             details={"column": "id"}).to_dict(),
+            DataCheckError(message="1 row(s) (20.0%) of target values are null",
+                           data_check_name="InvalidTargetDataCheck",
+                           message_code=DataCheckMessageCode.TARGET_HAS_NULL,
+                           details={"num_null_rows": 1, "pct_null_rows": 20}).to_dict(),
+            DataCheckError(message="lots_of_null has 1 unique value.",
+                           data_check_name="NoVarianceDataCheck",
+                           message_code=DataCheckMessageCode.NO_VARIANCE,
+                           details={"column": "lots_of_null"}).to_dict(),
+            DataCheckError(message="all_null has 0 unique value.",
+                           data_check_name="NoVarianceDataCheck",
+                           message_code=DataCheckMessageCode.NO_VARIANCE,
+                           details={"column": "all_null"}).to_dict(),
+            DataCheckError(message="also_all_null has 0 unique value.",
+                           data_check_name="NoVarianceDataCheck",
+                           message_code=DataCheckMessageCode.NO_VARIANCE,
+                           details={"column": "also_all_null"}).to_dict()]
 
 
 def test_default_data_checks_classification():
@@ -64,22 +91,33 @@ def test_default_data_checks_classification():
     y = pd.Series([0, 1, np.nan, 1, 0])
     data_checks = DefaultDataChecks("binary")
 
-    leakage = [DataCheckWarning("Column 'has_label_leakage' is 95.0% or more correlated with the target", "LabelLeakageDataCheck")]
+    leakage = [DataCheckWarning(message="Column 'has_label_leakage' is 95.0% or more correlated with the target",
+                                data_check_name="TargetLeakageDataCheck",
+                                message_code=DataCheckMessageCode.TARGET_LEAKAGE,
+                                details={"column": "has_label_leakage"}).to_dict()]
+    imbalance = [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [1.0, 0.0]",
+                                data_check_name="ClassImbalanceDataCheck",
+                                message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
+                                details={"target_values": [1.0, 0.0]}).to_dict()]
 
-    assert data_checks.validate(X, y) == messages[:3] + leakage + messages[3:]
+    assert data_checks.validate(X, y) == {"warnings": messages[:3] + leakage, "errors": messages[3:] + imbalance}
 
     data_checks = DataChecks(DefaultDataChecks._DEFAULT_DATA_CHECK_CLASSES,
                              {"InvalidTargetDataCheck": {"problem_type": "binary"}})
-    assert data_checks.validate(X, y) == messages[:3] + leakage + messages[3:]
+    assert data_checks.validate(X, y) == {"warnings": messages[:3] + leakage, "errors": messages[3:]}
 
+    imbalance = [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0.0, 2.0, 1.0]",
+                                data_check_name="ClassImbalanceDataCheck",
+                                message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
+                                details={"target_values": [0.0, 2.0, 1.0]}).to_dict()]
     # multiclass
     y = pd.Series([0, 1, np.nan, 2, 0])
     data_checks = DefaultDataChecks("multiclass")
-    assert data_checks.validate(X, y) == messages
+    assert data_checks.validate(X, y) == {"warnings": messages[:3], "errors": messages[3:] + imbalance}
 
     data_checks = DataChecks(DefaultDataChecks._DEFAULT_DATA_CHECK_CLASSES,
                              {"InvalidTargetDataCheck": {"problem_type": "multiclass"}})
-    assert data_checks.validate(X, y) == messages
+    assert data_checks.validate(X, y) == {"warnings": messages[:3], "errors": messages[3:]}
 
 
 def test_default_data_checks_regression():
@@ -93,14 +131,23 @@ def test_default_data_checks_regression():
     y2 = pd.Series([5] * 4)
 
     data_checks = DefaultDataChecks("regression")
-    assert data_checks.validate(X, y) == messages
+    assert data_checks.validate(X, y) == {"warnings": messages[:3], "errors": messages[3:]}
 
     # Skip Invalid Target
-    assert data_checks.validate(X, y2) == messages[:3] + messages[4:] + [DataCheckError("Y has 1 unique value.", "NoVarianceDataCheck")]
+    assert data_checks.validate(X, y2) == {"warnings": messages[:3], "errors": messages[4:] + [DataCheckError(message="Y has 1 unique value.",
+                                                                                                              data_check_name="NoVarianceDataCheck",
+                                                                                                              message_code=DataCheckMessageCode.NO_VARIANCE,
+                                                                                                              details={"column": "Y"}).to_dict()]}
 
     data_checks = DataChecks(DefaultDataChecks._DEFAULT_DATA_CHECK_CLASSES,
                              {"InvalidTargetDataCheck": {"problem_type": "regression"}})
-    assert data_checks.validate(X, y) == messages
+    assert data_checks.validate(X, y) == {"warnings": messages[:3], "errors": messages[3:]}
+
+
+def test_default_data_checks_time_series_regression():
+    regression_data_check_classes = [check.__class__ for check in DefaultDataChecks("regression").data_checks]
+    ts_regression_data_check_classes = [check.__class__ for check in DefaultDataChecks("time series regression").data_checks]
+    assert regression_data_check_classes == ts_regression_data_check_classes
 
 
 def test_data_checks_init_from_classes():
