@@ -8,13 +8,15 @@ def correct_model_families():
     correct_model_families = [ModelFamily.LINEAR_MODEL, ModelFamily.LIGHTGBM,
                               ModelFamily.RANDOM_FOREST, ModelFamily.XGBOOST,
                               ModelFamily.CATBOOST, ModelFamily.EXTRA_TREES,
-                              ModelFamily.DECISION_TREE, ModelFamily.BASELINE, ModelFamily.NONE]
+                              ModelFamily.DECISION_TREE, ModelFamily.ENSEMBLE,
+                              ModelFamily.BASELINE, ModelFamily.NONE]
     yield correct_model_families
 
 
 def test_handle_string(correct_model_families):
-    model_families = ['linear_model', 'lightgbm', 'random_forest', 'xgboost',
-                      'catboost', 'extra_trees', 'decision_tree', 'baseline', 'none']
+    model_families = ['linear_model', 'lightgbm', 'random_forest',
+                      'xgboost', 'catboost', 'extra_trees', 'decision_tree',
+                      'ensemble', 'baseline', 'none']
     for model_family in zip(model_families, correct_model_families):
         assert handle_model_family(model_family[0]) == model_family[1]
 
