@@ -300,9 +300,11 @@ def _convert_to_woodwork_structure(data):
         ww_data = pd.DataFrame(ww_data)
 
     # Convert pandas data structures to Woodwork data structures
+    ww_data = ww_data.copy()
     if isinstance(ww_data, pd.Series):
         return ww.DataColumn(ww_data)
-    return ww.DataTable(ww_data, copy_dataframe=True)
+
+    return ww.DataTable(ww_data)
 
 
 def _convert_woodwork_types_wrapper(pd_data):
